@@ -48,6 +48,7 @@
 void safeReplaceString(char** oldstr, const gchar *newstr, MainView *mainview);
 void maybe_save_file(MainView *mainview);
 void save_mod_file(MainView *mainview);
+void setCurrentGroup(MainView *mainview, gchar *group);
 
 /* activate grid */
 void callback_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, GtkTreeViewColumn *column, MainView *mainview) {
@@ -58,22 +59,22 @@ void callback_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, GtkTre
 void callback_hildon_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, MainView *mainview) {
 	GtkTreeIter iter;
 	rec *onrec=NULL;
+	gchar *label=NULL;
+	gboolean groupExpand=FALSE;
 	g_assert(mainview != NULL && mainview->data != NULL );
 	if ( !gtk_tree_model_get_iter(GTK_TREE_MODEL(mainview->store), &iter, path) ) {
 		return;
 	}
-	gtk_tree_model_get(GTK_TREE_MODEL(mainview->store), &iter,
-	    DATA_COLUMN, &onrec,
-	    -1);
-	/*
-	onrec=g_object_get_data (G_OBJECT(&iter), "r");
-	*/
+	gtk_tree_model_get(GTK_TREE_MODEL(mainview->store), &iter, LABEL_COLUMN, &label, DATA_COLUMN, &onrec, GROUP_COLUMN, &groupExpand, -1);
 	if (onrec!=NULL) {
 		show_rec(mainview, onrec, FALSE);
-	} else if (gtk_tree_view_collapse_row(treeView, path)) {
-		gtk_tree_view_expand_row(treeView, path, FALSE);
+		setCurrentGroup(mainview, onrec->group);
 	} else {
-		gtk_tree_view_collapse_row(treeView, path);
+		setCurrentGroup(mainview, label);
+		if (groupExpand) {
+			gtk_tree_view_collapse_row (treeView, path);
+		}
+		gtk_tree_store_set(mainview->store, &iter, GROUP_COLUMN, !groupExpand, -1);
 	}
 }
 
@@ -151,7 +152,7 @@ void callback_rec_response(GtkDialog *dialog, gint response, MainView *mainview)
 			gtk_clipboard_set_text(mainview->clipboard, rec->password, -1);
 			break;
 		case 4:
-			if ((recwindow->editable) && (CONFRESP_YES==interface_yes_no_note(mainview, "Confirm Delete?"))) {
+			if ((recwindow->editable) && (CONFRESP_YES==interface_yes_no_note(mainview, _("Confirm Delete ?")))) {
 				unshow_rec(mainview);
 				delete_rec(rec);
 				populate_treeView(mainview); /* redraw grid */
@@ -301,7 +302,7 @@ gboolean callback_tag_event(GtkTextTag *tag, GObject *object, GdkEvent *event, G
 			}
 		}
 		text = gtk_text_iter_get_text(&start, &end);
-		g_print("text associ au tag %s\n", text);
+//		g_print("text associ au tag %s\n", text);
 		launch_browser(text, mainView);
 	}
 	return FALSE;
@@ -347,7 +348,7 @@ gboolean exit_event_handler( GtkWidget *widget, GdkEvent  *event, MainView *main
 void maybe_save_file(MainView *mainview) {
 /* save changes if file changed, with requester*/
     if (mainview->pass && mainview->file_edited) {
-        if (CONFRESP_YES==interface_yes_no_note(mainview, "Save Changes?")) { 
+        if (CONFRESP_YES==interface_yes_no_note(mainview, _("Save Changes ?"))) { 
             if (!mainview->file_name) {  /* should never happen because file name set on open */
                 mainview->file_name = interface_file_chooser(mainview, GTK_FILE_CHOOSER_ACTION_SAVE);
             }
@@ -367,9 +368,14 @@ void save_mod_file(MainView *mainview) {
 }
 
 gchar * getCurrentGroup(MainView *mainview ) {
-	//TODO get the current Group from the selected one
-	gchar *group = g_strdup("");
-	return group;
+	return mainview->currentGroup;
+}
+
+void setCurrentGroup(MainView *mainview, gchar *group) {
+	if (group != NULL && group[0] != '\0' && strcmp(group, _(DEFAULT_GROUP)) != 0) {
+		g_free(mainview->currentGroup);
+		mainview->currentGroup = g_strdup(group);
+	}
 }
 
 /* add entry */
@@ -386,7 +392,7 @@ void callback_add_entry ( GtkAction * action, MainView *mainview ) {
 void callback_change_password(GtkAction * action, MainView *mainview) {
 	char *newpass=NULL;
 	g_assert(mainview != NULL && mainview->data != NULL );
-	newpass=get_password(mainview, "Change Password", PWD_DLG_CHANGE);
+	newpass=get_password(mainview, _("Change Password"), PWD_DLG_CHANGE);
 	if (newpass) {
 		mainview->pass=newpass;
 		mainview->file_edited = TRUE;
@@ -400,14 +406,16 @@ void callback_file_new(GtkAction * action, MainView *mainview) {
 	/* maybe_save_file(mainview); */
 	save_mod_file(mainview);
 	close_file(mainview);
-	newpass=get_password(mainview, "New Password", PWD_DLG_NEW);
+	newpass=get_password(mainview, _("New Password"), PWD_DLG_NEW);
 	if (newpass) {
 		mainview->pass=newpass;
-		add_new_record("new", getCurrentGroup(mainview));
-		populate_treeView(mainview);
+//		add_new_record("new", "Group");
+//		populate_treeView(mainview);
 		/* maybe_save_file(mainview); */
 		write_pwsafe_file(mainview);  /* force set file name */
-		interface_show_state(mainview) ;
+		if (mainview->file_name != NULL) {
+			interface_show_state(mainview) ;
+		}
 	}
 }
 
@@ -503,6 +511,17 @@ void callback_filter(GtkWidget *widget, MainView *mainview ) {
     populate_treeView(mainview);
 }
 
+
+gboolean callback_tree_key_pressed(GtkTreeView *treeView, GdkEventKey *event, MainView *mainview) {
+	if (event->string[0]!='\0') {
+		gtk_entry_set_text(GTK_ENTRY(mainview->filter_tb), event->string);
+		callback_filter(mainview->filter_tb, mainview);
+		gtk_widget_grab_focus(mainview->filter_tb);
+		gtk_editable_set_position(GTK_EDITABLE(mainview->filter_tb), -1);
+	}
+	return FALSE;
+}
+
 gint getEntryLength(GtkEntry *entry) {
 #if MAEMO_VERSION_MAJOR < 5
 	gchar *text;
@@ -662,3 +681,5 @@ DBusHandlerResult dbus_handle_mce_message(DBusConnection *con, DBusMessage *msg,
 	}
 	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
+
+
