@@ -167,7 +167,7 @@ gchar *get_password(MainView *main, gchar *caption, gint pwdDlgType) {
 	pwUi->result = NULL;
 	pwUi->msg = NULL;
 	
-	pwUi->dialog = gtk_dialog_new_with_buttons(caption, GTK_WINDOW(main->data->main_view), GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, NULL);
+	pwUi->dialog = gtk_dialog_new_with_buttons(caption, GTK_WINDOW(main->data->main_view), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, NULL);
 	table = gtk_table_new(pwdDlgType, 2, TRUE);
 
 #if MAEMO_VERSION_MAJOR < 5
@@ -181,8 +181,6 @@ gchar *get_password(MainView *main, gchar *caption, gint pwdDlgType) {
 	contentArea = gtk_dialog_get_content_area(GTK_DIALOG(pwUi->dialog));
 
 	pwUi->button =  hildon_button_new_with_text(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, _("OK"), NULL);
-	image = gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
-	hildon_button_set_image (HILDON_BUTTON (pwUi->button), image);
 	pwUi->entry1=hildon_entry_new(HILDON_SIZE_AUTO);
 #endif
 	gtk_container_add (GTK_CONTAINER (actionArea), pwUi->button);
@@ -344,19 +342,27 @@ gboolean addEntryToGroup(GtkTreeStore *store, GtkTreeIter *groupIter, rec *data)
 gboolean searchGroup (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, SearchGroup *sg) {
 	rec *data;
 	gchar *label;
+	gchar *group;
 	
 	gtk_tree_model_get(model, iter, LABEL_COLUMN, &label, DATA_COLUMN, &data,  -1);
-	if (data == NULL && label != NULL && g_ascii_strcasecmp( emptynull(sg->data->group), label) == 0) {
+	if (sg->data->group == NULL || sg->data->group[0] == '\0') {
+		group = g_strdup(_(DEFAULT_GROUP));
+	} else {
+		group = g_strdup(sg->data->group);
+	}
+	if (data == NULL && label != NULL && g_ascii_strcasecmp(group, label) == 0) {
 		sg->found = addEntryToGroup(GTK_TREE_STORE(model), iter, sg->data);
-		
+		g_free(group);
 		return TRUE;
 	}
+	g_free(group);
 	return FALSE;
 }
 
 gboolean addEntryToTree(MainView *main, rec *data) {
 	SearchGroup *sg;
 	GtkTreeIter groupIter;
+	gchar *group;
 	
 	sg = g_new0(SearchGroup, 1);
 	sg->data = data;
@@ -369,7 +375,17 @@ gboolean addEntryToTree(MainView *main, rec *data) {
 	
 	//Create the group 
 	gtk_tree_store_append(main->store, &groupIter, NULL);
-	gtk_tree_store_set(main->store, &groupIter, LABEL_COLUMN, emptynull(data->group), ICON_COLUMN, GTK_STOCK_DIRECTORY, DATA_COLUMN, NULL, -1);
+	
+	if (data->group == NULL || data->group[0] == '\0') {
+		group = g_strdup(_(DEFAULT_GROUP));
+	} else {
+		group = g_strdup(data->group);
+	}
+	gtk_tree_store_set(main->store, &groupIter, LABEL_COLUMN, group, ICON_COLUMN, GTK_STOCK_DIRECTORY, DATA_COLUMN, NULL, GROUP_COLUMN, FALSE, -1);
+	
+	if (main->currentGroup == NULL && data->group != NULL) {
+		main->currentGroup = g_strdup(data->group);
+	}
 	
 	//Add the Entry
 	addEntryToGroup(main->store, &groupIter, data);
@@ -603,14 +619,6 @@ void interface_show_state(MainView *main) {
 	interface_show_item(main->add_item, fopen);
 	
 	if (GTK_IS_WIDGET(main->add_tb)) {	/* ignore toolbar if it's not there (eg. during app close) */
-#if MAEMO_VERSION_MAJOR < 5
-		gtk_widget_set_sensitive(GTK_WIDGET(main->new_tb), !fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->open_tb), !fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->close_tb), fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->save_tb), fopen);
-		gtk_widget_set_sensitive(GTK_WIDGET(main->saveas_tb), fopen);
-#endif
-		gtk_widget_set_sensitive(GTK_WIDGET(main->change_password_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->add_tb), fopen);
 		gtk_editable_set_editable(GTK_EDITABLE(main->filter_tb), fopen);
 		if (!fopen) {
@@ -651,19 +659,8 @@ static void create_toolbar ( MainView *main ) {
 
 	/* Make menus and buttons to toolbar: */
 	/* Create toolitems using defined items from stock */
-#if MAEMO_VERSION_MAJOR < 5
-	main->new_tb = gtk_tool_button_new_from_stock(GTK_STOCK_NEW);
-	main->open_tb = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
-	main->close_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CLOSE);
-	main->save_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE);
-	main->saveas_tb = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE_AS);
-	main->separator_tb1 = gtk_separator_tool_item_new();
-	main->fullscreen_tb = gtk_tool_button_new_from_stock( GTK_STOCK_ZOOM_FIT );
-    main->separator_tb3 = gtk_separator_tool_item_new();
-#endif
 	main->add_tb = gtk_tool_button_new_from_stock(GTK_STOCK_ADD);
-	main->change_password_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CONVERT);
-	main->separator_tb2 = gtk_separator_tool_item_new();
+	main->separator_tb = gtk_separator_tool_item_new();
     
     /* create filter text entry in a container */
     main->filter_item_tb = gtk_tool_item_new();
@@ -675,38 +672,15 @@ static void create_toolbar ( MainView *main ) {
     hildon_entry_set_placeholder (HILDON_ENTRY (main->filter_tb), _("Filter"));
 #endif
 
-    /* gtk_entry_set_max_length( GTK_ENTRY(main->filter_tb) , (gint) 24);  */
     gtk_container_add( GTK_CONTAINER( main->filter_item_tb ) , main->filter_tb);
 	
     /* Insert items to toolbar */
-#if MAEMO_VERSION_MAJOR < 5
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->new_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->open_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->close_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->save_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->saveas_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb1, -1);
-#endif
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->add_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->change_password_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb2, -1);
-#if MAEMO_VERSION_MAJOR < 5
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->fullscreen_tb, -1);
-	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb3, -1);
-#endif
+	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->filter_item_tb, -1);
 
 	/* Connect signals to buttons */
-#if MAEMO_VERSION_MAJOR < 5
-	g_signal_connect(G_OBJECT(main->new_tb), "clicked", G_CALLBACK(callback_file_new), main);
-	g_signal_connect(G_OBJECT(main->open_tb), "clicked", G_CALLBACK(callback_file_open), main);
-	g_signal_connect(G_OBJECT(main->close_tb), "clicked", G_CALLBACK(callback_file_close), main);
-	g_signal_connect(G_OBJECT(main->save_tb), "clicked", G_CALLBACK(callback_file_save), main);
-	g_signal_connect(G_OBJECT(main->saveas_tb), "clicked", G_CALLBACK(callback_file_saveas), main);
-	g_signal_connect(G_OBJECT(main->fullscreen_tb), "clicked", G_CALLBACK(callback_fullscreen), main);
-#endif
 	g_signal_connect(G_OBJECT(main->add_tb), "clicked", G_CALLBACK(callback_add_entry), main);
-	g_signal_connect(G_OBJECT(main->change_password_tb), "clicked", G_CALLBACK(callback_change_password), main);
 	g_signal_connect(G_OBJECT(main->filter_tb), "changed", G_CALLBACK(callback_filter), main);
 	
 	/* Attach toolbar to main view */
@@ -724,11 +698,8 @@ void create_textarea( MainView *main ) {
 	GtkTreeSelection *select;
 		
 	main->font_desc = pango_font_description_from_string ("Nokia Sans 16");
-	main->store=gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+	main->store=gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 	main->treeView=gtk_tree_view_new_with_model(GTK_TREE_MODEL(main->store));
-#if MAEMO_VERSION_MAJOR >= 5
-	gtk_tree_view_set_show_expanders(GTK_TREE_VIEW (main->treeView), TRUE);
-#endif
 	renderer = gtk_cell_renderer_pixbuf_new();
 	column = gtk_tree_view_column_new_with_attributes (_("Icon"), renderer, "stock-id", ICON_COLUMN, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (main->treeView), column);
@@ -741,13 +712,14 @@ void create_textarea( MainView *main ) {
         select = gtk_tree_view_get_selection (GTK_TREE_VIEW (main->treeView));
         gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
         gtk_tree_view_columns_autosize(GTK_TREE_VIEW(main->treeView));
-				
+	
     /* Connect signals */
 #if MAEMO_VERSION_MAJOR >= 5
 	g_signal_connect (G_OBJECT(main->treeView), "hildon-row-tapped", G_CALLBACK (callback_hildon_activate_treeView), main);
 #else
 	g_signal_connect (G_OBJECT(main->treeView), "row-activated", G_CALLBACK (callback_activate_treeView), main);
 #endif
+g_signal_connect (G_OBJECT(main->treeView), "key-press-event", G_CALLBACK (callback_tree_key_pressed), main);
 }
 
 /* toggle fullscreen */
