@@ -39,17 +39,19 @@
 #include <hildon-widgets/hildon-program.h>
 #endif
 
-#include <libintl.h>
+//#include <libintl.h>
 #include <locale.h>
+#include <glib/gi18n.h>
+
 #include <libosso.h>
 /* 
  * #include <libmb/mbutil.h>
  */
 
-#define _(String) gettext(String)
+//#define _(String) gettext(String)
 
 #define APP_NAME "pwsafe"
-#define APP_VER "1.4.0"
+#define APP_VER "1.6.0"
 
 extern void save_mod_file(MainView *mainview);
 extern void close_file(MainView *mainview);
@@ -86,9 +88,9 @@ int main( int argc, char* argv[] ) {
 
 	/* Initialise the locale stuff */
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset(PACKAGE, "UTF-8");
-	textdomain(PACKAGE);
+	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
 	recs=NULL;
 	
